scxpand.util.training\_utils
============================

.. automodule:: scxpand.util.training_utils

   
   .. rubric:: Functions

   .. autosummary::
   
      call_training_function
      validate_and_setup_common
   